@@ -6,10 +6,10 @@ BEGIN {
   $ElasticSearchX::Model::Generator::DocumentGenerator::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $ElasticSearchX::Model::Generator::DocumentGenerator::VERSION = '0.1.1';
+  $ElasticSearchX::Model::Generator::DocumentGenerator::VERSION = '0.1.2';
 }
 
-# ABSTRACT: Moose Class generation backend for Documents/Types.
+# ABSTRACT: Moose Class generation back end for Documents/Types.
 
 use 5.10.0;
 use Moo;
@@ -43,12 +43,13 @@ EOF
   my @attributes;
   for my $property_name ( sort { $a cmp $b } $self->generator_base->property_names( $args{index}, $args{typename} ) ) {
     my $property = $self->generator_base->property( $args{index}, $args{typename}, $property_name );
-    push @attributes, $self->attribute_generator->generate(
+    push @attributes,
+      $self->attribute_generator->generate(
       index        => $args{index},
       typename     => $args{typename},
       propertyname => $property_name,
       propertydata => $property,
-    );
+      );
   }
 
   require ElasticSearchX::Model::Generator::Generated::Document;
@@ -64,17 +65,18 @@ no Moo;
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
 
 =head1 NAME
 
-ElasticSearchX::Model::Generator::DocumentGenerator - Moose Class generation backend for Documents/Types.
+ElasticSearchX::Model::Generator::DocumentGenerator - Moose Class generation back end for Documents/Types.
 
 =head1 VERSION
 
-version 0.1.1
+version 0.1.2
 
 =head1 METHODS
 
@@ -98,10 +100,9 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
